
# Class: LayerParams


Parameters for each layer of a neural network.

URI: [https://w3id.org/neat/LayerParams](https://w3id.org/neat/LayerParams)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Layer]++-%20parameters%200..1>[LayerParams&#124;units:integer%20%3F;activation:activation_enum%20%3F;rate:float%20%3F],[Layer])](https://yuml.me/diagram/nofunky;dir:TB/class/[Layer]++-%20parameters%200..1>[LayerParams&#124;units:integer%20%3F;activation:activation_enum%20%3F;rate:float%20%3F],[Layer])

## Referenced by Class

 *  **None** *[➞parameters](layer__parameters.md)*  <sub>0..1</sub>  **[LayerParams](LayerParams.md)**

## Attributes


### Own

 * [➞units](layerParams__units.md)  <sub>0..1</sub>
     * Range: [Integer](types/Integer.md)
 * [➞activation](layerParams__activation.md)  <sub>0..1</sub>
     * Description: Activation layer type
     * Range: [activation_enum](activation_enum.md)
 * [➞rate](layerParams__rate.md)  <sub>0..1</sub>
     * Range: [Float](types/Float.md)
